@@ -8,7 +8,7 @@ from astropy.convolution import convolve
 from astropy.convolution import Gaussian2DKernel
 from scipy.ndimage import filters
 import matplotlib.colors as colors
-import os
+import os, sys
 
 #matplotlib.rcParams['ps.useafm'] = True
 #matplotlib.rcParams['pdf.use14corefonts'] = True
@@ -464,7 +464,7 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
 
     if cent[0]  == 0 and cent[1]  == 0 :
        cent[0]  = ima.shape[1]*0.5 ; cent[1]  = ima.shape[0]*0.5
-
+    
     x = delta[0]*scale
     y = delta[1]*scale
 
@@ -491,7 +491,10 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
         if nivels is None:
             nivels = np.linspace(imin, imax, ncont)
         if sigmag != 0:
-            kernel = Gaussian2DKernel(x_stddev=sigmag)
+            if sys.version_info[0] == 3:
+                kernel = Gaussian2DKernel(x_stddev=sigmag)
+            else:
+                kernel = Gaussian2DKernel(stddev=sigmag)
             smooth = convolve(temp, kernel)
             smooth[np.isnan(temp)]=np.nan
         else:
